import { SolanaInpageProvider, EthProvider, SuiProvider, BtcProvider } from '@phantom/web3-providers';
import React, { ReactNode } from 'react';

interface LoginOptionsProps {
    onGoogleLogin: () => void;
    onAppleLogin: () => void;
}
declare const LoginOptions: React.FC<LoginOptionsProps>;

type Addresses = {
    solana: string;
    sui: string;
    evm: string;
    bitcoinTaproot: string;
    bitcoin: string;
};
interface Phantom {
    loginWithGoogle: (allowRefresh?: boolean) => Promise<Addresses[]>;
    loginWithApple: (allowRefresh?: boolean) => Promise<Addresses[]>;
    dismissBrowser: () => Promise<void>;
    logout: () => Promise<void>;
    hasStoredSession: () => Promise<boolean>;
    getStoredAddresses: () => Promise<Addresses[] | null>;
    providers: {
        solana: SolanaInpageProvider;
        ethereum: EthProvider;
        sui: SuiProvider;
        bitcoin: BtcProvider;
    };
}
interface PhantomConfig {
    sdkKey: string;
    redirectURI: string;
    autoShowLoginIfNeeded?: boolean;
}

declare const createPhantom: (config: PhantomConfig) => Promise<Phantom>;

interface PhantomContextValue {
    phantom: Phantom | null;
    isLoggingIn: boolean;
    isLoggedIn: boolean;
    addresses: Addresses[] | null;
    showLoginOptions: () => void;
    hideLoginOptions: () => void;
    logout: () => Promise<void>;
}
declare const usePhantom: () => PhantomContextValue;
interface PhantomProviderProps {
    children: ReactNode;
    config: PhantomConfig;
}
declare const PhantomProvider: React.FC<PhantomProviderProps>;

export { LoginOptions, PhantomProvider, createPhantom, usePhantom };
